@@ -1,26 +1,38 @@
-#**********************************************************************************************************************************
-#**********************************************************************************************************************************
-#
-#  ParaMonte: plain powerful parallel Monte Carlo library.
-#
-#  Copyright (C) 2012-present, The Computational Data Science Lab
-#
-#  This file is part of ParaMonte library.
-#
-#  ParaMonte is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU Lesser General Public License as published by
-#  the Free Software Foundation, version 3 of the License.
-#
-#  ParaMonte is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU Lesser General Public License for more details.
-#
-#  You should have received a copy of the GNU Lesser General Public License
-#  along with ParaMonte.  If not, see <https://www.gnu.org/licenses/>.
-#
-#**********************************************************************************************************************************
-#**********************************************************************************************************************************
+####################################################################################################################################
+####################################################################################################################################
+####
+####   ParaMonte: plain powerful parallel Monte Carlo library.
+####
+####   Copyright (C) 2012-present, The Computational Data Science Lab
+####
+####   This file is part of the ParaMonte library.
+####
+####   ParaMonte is free software: you can redistribute it and/or modify it
+####   under the terms of the GNU Lesser General Public License as published
+####   by the Free Software Foundation, version 3 of the License.
+####
+####   ParaMonte is distributed in the hope that it will be useful,
+####   but WITHOUT ANY WARRANTY; without even the implied warranty of
+####   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+####   GNU Lesser General Public License for more details.
+####
+####   You should have received a copy of the GNU Lesser General Public License
+####   along with the ParaMonte library. If not, see,
+####
+####       https://github.com/cdslaborg/paramonte/blob/master/LICENSE
+####
+####   ACKNOWLEDGMENT
+####
+####   As per the ParaMonte library license agreement terms,
+####   if you use any parts of this library for any purposes,
+####   we ask you to acknowledge the use of the ParaMonte library
+####   in your work (education/research/industry/development/...)
+####   by citing the ParaMonte library as described on this page:
+####
+####       https://github.com/cdslaborg/paramonte/blob/master/ACKNOWLEDGMENT.md
+####
+####################################################################################################################################
+####################################################################################################################################
 
 import numpy as _np
 import typing as _tp
@@ -44,98 +56,134 @@ from _visutils import Target, ParaMonteFigure
 
 class DensityMapPlot:
     """
-    This is the DensityMapPlot class for generating instances 
+
+    .. py:class:: DensityMapPlot
+
+    This is the ``DensityMapPlot`` class for generating instances 
     of 2D densitymap figures based on seaborns library's 
-    kdeplot() and functions.
+    ``kdeplot()`` and functions.
 
-    Usage
-    -----
-    first generate an object of this class by optionally 
-    passing the following parameters described below. Then call 
-    the plot() method. The generated object is also callable with 
-    the same input parameters as the object's constructor.
+        **Usage**
 
-    Parameters
-    ----------
-        dataFrame
-            a Pandas dataframe from which the selected data will be plotted.
-        xcolumn
-            optional argument that determines the columns of dataframe to serve as 
-            the x-values. It can have three forms:
-                1. a column index of the input dataframe.
-                2. a column name of the input dataframe (as in dataFrame.columns).
-            Examples:
-                1. xcolumn = 0
-                2. xcolumn = [0]
-                3. xcolumn = ["SampleVariable1"]
-        If not provided, the default will be the first column of the input dataFrame.
-        ycolumn
-            optional argument that determines the columns of dataframe to serve as 
-            the y-values. It can have three forms:
-                1. a column index of the input dataframe.
-                2. a column name of the input dataframe (as in dataFrame.columns).
-            Examples:
-                1. ycolumn = 0
-                2. ycolumn = [0]
-                3. ycolumn = ["SampleVariable2"]
-        If not provided, the default will be the second column of the input dataFrame.
-        rows
-            optional argument that determines the rows of dataframe 
-            to be visualized. It can be either:
-                1. a range(start,stop,step), or, 
-                2. a list of row indices in dataFrame.index.
-            Examples:
-                1. rows = range(17,7,-2)
-                2. rows = [i for i in range(7,17)]
-            If not provided, the default will include all rows of the dataframe.
-        set_kws
-            optional dictionary of keyword arguments to be passed to seaborn's 
-            set() function. For example: 
-                set_kws = {"style":"darkgrid"}
-            if set to None, then no call to set() function will be made.
-        figure_kws
-            optional dictionary of keyword arguments to be passed to matplotlib's 
-            figure() function. For example: 
-                figure_kws = {"facecolor":"w","dpi":150}
-        kdeplot_kws
-            optional dictionary of keyword arguments to be passed to seaborn's 
-            kdeplot() function. For example: 
-                kdeplot_kws = {"n_levels":100,"shade":True,"shade_lowest":True,"cmap":"Blues"}
-            If not set, the default will be None and no kdeplot will be plotted.
-            If both kdeplot_kws and jointplot_kws are set, a jointplot will be plotted.
-        jointplot_kws
-            optional dictionary of keyword arguments to be passed to seaborn's 
-            jointplot() function. For example: 
-                kdeplot_kws = {"n_levels":100,"shade":True,"shade_lowest":True,"cmap":"Blues"}
-            If not set, the default will be None and no jointplot will be plotted.
-            If both kdeplot_kws and jointplot_kws are set, a jointplot will be plotted.
-        outputFile
-            optional string representing the name of the output file in which 
-            the figure will be saved. If not provided, no output file will be generated.
+            First generate an object of this class by optionally 
+            passing the following parameters described below. Then call 
+            the ``plot()`` method. The generated object is also callable with 
+            the same input parameters as the object's constructor.
 
-    Attributes
-    ----------
-        All of the parameters described above, except dataFrame.
-            a reference to the dataFrame will be implicitly stored in the object.
-        target
-            a callable object of ParaMonte library's class Target which can 
-            be used to add target point and lines to the current active plot.
-        currentFig
-            an object of class ParaMonteFigure which is initially None, but upon 
-            making a plot, is populated with attributes representing all outputs 
-            from matplotlib/seaborn function calls, with the following attributes:
-                figure
-                    the output of matplotlib's figure() function.
-                kdeplot
-                    the output of seaborn's kdeplot() function.
-                jointplot
-                    the output of seaborn's jointplot() function.
+        **Parameters**
 
-    Returns
-    -------
-        DensityMapPlot
+            dataFrame
+                a Pandas dataframe from which the selected data will be plotted.
 
-    ----------------------------------------------------------------------
+            xcolumn
+                optional argument that determines the columns of dataframe to serve as 
+                the x-values. It can have three forms:
+
+                    1. a column index of the input dataframe.
+                    2. a column name of the input dataframe (as in ``dataFrame.columns``).
+
+                Examples:
+
+                    1. ``xcolumn = 0``
+                    2. ``xcolumn = [0]``
+                    3. ``xcolumn = ["SampleVariable1"]``
+
+            If not provided, the default will be the first column of the input dataFrame.
+
+            ycolumn
+                optional argument that determines the columns of dataframe to serve as 
+                the y-values. It can have three forms:
+
+                    1. a column index of the input dataframe.
+                    2. a column name of the input dataframe (as in ``dataFrame.columns``).
+
+                Examples:
+
+                    1. ``ycolumn = 0``
+                    2. ``ycolumn = [0]``
+                    3. ``ycolumn = ["SampleVariable2"]``
+
+            If not provided, the default will be the second column of the input dataFrame.
+
+            rows
+                optional argument that determines the rows of dataframe 
+                to be visualized. It can be either:
+
+                    1. a ``range(start,stop,step)``, or, 
+                    2. a list of row indices in dataFrame.index.
+
+                Examples:
+
+                    1. ``rows = range(17,7,-2)``
+                    2. ``rows = [i for i in range(7,17)]``
+
+                If not provided, the default will include all rows of the dataframe.
+
+            set_kws
+                optional dictionary of keyword arguments to be passed to seaborn's 
+                ``set()`` function. For example: 
+
+                    ``set_kws = {"style":"darkgrid"}``
+
+                if set to ``None``, then no call to ``set()`` function will be made.
+
+            figure_kws
+                optional dictionary of keyword arguments to be passed to matplotlib's 
+                ``figure()`` function. For example: 
+
+                    ``figure_kws = {"facecolor":"w","dpi":150}``
+
+            kdeplot_kws
+                optional dictionary of keyword arguments to be passed to seaborn's 
+                ``kdeplot()`` function. For example: 
+
+                    ``kdeplot_kws = {"n_levels":100,"shade":True,"shade_lowest":True,"cmap":"Blues"}``
+
+                If not set, the default will be None and no kdeplot will be plotted.
+                If both ``kdeplot_kws`` and ``jointplot_kws`` are set, a jointplot will be plotted.
+
+            jointplot_kws
+                optional dictionary of keyword arguments to be passed to seaborn's 
+                ``jointplot()`` function. For example: 
+
+                    ``kdeplot_kws = {"n_levels":100,"shade":True,"shade_lowest":True,"cmap":"Blues"}``
+
+                If not set, the default will be None and no jointplot will be plotted.
+                If both ``kdeplot_kws`` and ``jointplot_kws`` are set, a jointplot will be plotted.
+
+            outputFile
+                optional string representing the name of the output file in which 
+                the figure will be saved. If not provided, no output file will be generated.
+
+        **Attributes**
+
+            All of the parameters described above, except dataFrame.
+                a reference to the dataFrame will be implicitly stored in the object.
+
+            target
+                a callable object of ParaMonte library's class Target which can 
+                be used to add target point and lines to the current active plot.
+
+            currentFig
+                an object of class ParaMonteFigure which is initially None, but upon 
+                making a plot, is populated with attributes representing all outputs 
+                from matplotlib/seaborn function calls, with the following attributes:
+
+                    figure
+                        the output of matplotlib's ``figure()`` function.
+
+                    kdeplot
+                        the output of seaborn's ``kdeplot()`` function.
+
+                    jointplot
+                        the output of seaborn's ``jointplot()`` function.
+
+        **Returns**
+
+            self
+                an object of class ``DensityMapPlot``
+
+    ---------------------------------------------------------------------------
     """
 
     def __init__( self
@@ -173,21 +221,26 @@ class DensityMapPlot:
                 , **kwargs
                 ):
         """
+
+        .. py:method:: __call__(self,reself = False, **kwargs)
+
         calls the plot() method of the current instance of the class.
 
-        Parameters
-        ----------
-            reself
-                logical variable. If True, an instance of the object 
-                will be returned upon exit to the calling routine.
-                The default value is False.
-            also, any attributes of the current instance of the class.
+            **Parameters**
 
-        Returns
-        -------
-            the object self if reself = True otherwise, None.
-            However, this method causes side-effects by manipulating 
-            the existing attributes of the object.
+                reself
+                    logical variable. If True, an instance of the object 
+                    will be returned upon exit to the calling routine.
+                    The default value is False.
+
+                also, 
+                    any attributes of the current instance of the class.
+
+            **Returns**
+
+                the object self if ``reself = True`` otherwise, None.
+                However, this method causes side-effects by manipulating 
+                the existing attributes of the object.
 
         """
 
@@ -208,17 +261,20 @@ class DensityMapPlot:
 
     def plot(self):
         """
+
+        .. py:method:: plot(self)
+
         Generate a line plot, or scatter plot, or both 
         from the selected columns of the object's dataframe.
 
-        Parameters
-        ----------
-            None
+            **Parameters**
 
-        Returns
-        -------
-            None. However, this method causes side-effects by manipulating 
-            the existing attributes of the object.
+                None
+
+            **Returns**
+
+                None. However, this method causes side-effects by manipulating 
+                the existing attributes of the object.
 
         """
 
@@ -301,18 +357,15 @@ class DensityMapPlot:
 
         # check data type
 
-        noDataPassed = False
+        noDataPassed = ""
         if self._dfref is None:
-            noDataPassed = True
-            fatalmsg = "It appears that no data has been passed for plotting.\n"
+            noDataPassed = "It appears that no data has been passed for plotting.\n"
         elif not isinstance(self._dfref,_wref.ref):
-            noDataPassed = True
-            fatalmsg = "It appears that you have messed with the\ninternal representation of data in the object.\n"
+            noDataPassed = "It appears that you have messed with the\ninternal representation of data in the object.\n"
         elif not isinstance(self._dfref(),_pd.DataFrame):
-            noDataPassed = True
-            fatalmsg = ""
+            noDataPassed = "The input data is not a pandas' dataframe.\n"
         if noDataPassed:
-            raise Exception ( fatalmsg
+            raise Exception ( noDataPassed
                             + "The input data must be a pandas' dataframe.\n"
                             + "Please pass a dataFrame to the constructor or at\n"
                             + "the time of calling the object (which is callable with\n"
