@@ -1,33 +1,39 @@
 ####################################################################################################################################
 ####################################################################################################################################
 ####
+####   MIT License
+####
 ####   ParaMonte: plain powerful parallel Monte Carlo library.
 ####
 ####   Copyright (C) 2012-present, The Computational Data Science Lab
 ####
 ####   This file is part of the ParaMonte library.
 ####
-####   ParaMonte is free software: you can redistribute it and/or modify it
-####   under the terms of the GNU Lesser General Public License as published
-####   by the Free Software Foundation, version 3 of the License.
+####   Permission is hereby granted, free of charge, to any person obtaining a 
+####   copy of this software and associated documentation files (the "Software"), 
+####   to deal in the Software without restriction, including without limitation 
+####   the rights to use, copy, modify, merge, publish, distribute, sublicense, 
+####   and/or sell copies of the Software, and to permit persons to whom the 
+####   Software is furnished to do so, subject to the following conditions:
 ####
-####   ParaMonte is distributed in the hope that it will be useful,
-####   but WITHOUT ANY WARRANTY; without even the implied warranty of
-####   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-####   GNU Lesser General Public License for more details.
+####   The above copyright notice and this permission notice shall be 
+####   included in all copies or substantial portions of the Software.
 ####
-####   You should have received a copy of the GNU Lesser General Public License
-####   along with the ParaMonte library. If not, see,
-####
-####       https://github.com/cdslaborg/paramonte/blob/master/LICENSE
+####   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
+####   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
+####   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
+####   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
+####   DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
+####   OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
+####   OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ####
 ####   ACKNOWLEDGMENT
 ####
-####   As per the ParaMonte library license agreement terms,
-####   if you use any parts of this library for any purposes,
-####   we ask you to acknowledge the use of the ParaMonte library
-####   in your work (education/research/industry/development/...)
-####   by citing the ParaMonte library as described on this page:
+####   ParaMonte is an honor-ware and its currency is acknowledgment and citations.
+####   As per the ParaMonte library license agreement terms, if you use any parts of 
+####   this library for any purposes, kindly acknowledge the use of ParaMonte in your 
+####   work (education/research/industry/development/...) by citing the ParaMonte 
+####   library as described on this page:
 ####
 ####       https://github.com/cdslaborg/paramonte/blob/master/ACKNOWLEDGMENT.md
 ####
@@ -36,7 +42,6 @@
 
 import os
 import sys
-import numpy as np
 import typing as tp
 import ctypes as ct
 
@@ -117,19 +122,19 @@ class ParaMonteSampler:
                 all other simulation specifications set by the user via 
                 sampler instance's `spec`-component attributes.
 
-                spec
+            spec
 
-                    A Python structure containing all simulation specifications.
-                    All simulation attributes are by default set to appropriate
-                    values at runtime. To override the default simulation
-                    specifications, set the ``spec`` attributes to some
-                    desired values of your choice.
+                A Python structure containing all simulation specifications.
+                All simulation attributes are by default set to appropriate
+                values at runtime. To override the default simulation
+                specifications, set the ``spec`` attributes to some
+                desired values of your choice.
 
-                    If you need help on any of the simulation specifications, try
-                    the supplied ``helpme()`` function in this component.
+                If you need help on any of the simulation specifications, try
+                the supplied ``helpme()`` function in this component.
 
-                    If you wish to reset some specifications to the default values, 
-                    simply set them to ``None``.
+                If you wish to reset some specifications to the default values, 
+                simply set them to ``None``.
 
         **Methods**
 
@@ -467,7 +472,7 @@ class ParaMonteSampler:
             else:
                 os.environ["PATH"] = pm.path.root
 
-            mpiFound = False
+            #mpiFound = False
             pathList = os.environ["PATH"].split(";")
             for path in pathList:
                 pathLower = path.lower().replace("\\","")
@@ -550,7 +555,7 @@ class ParaMonteSampler:
 
                 libName = libNamePrefix + pmcs + "_" + buildMode + "_dynamic_heap" + libNameSuffix
                 libPath = find_library(libName)
-                if libPath==None: libPath = os.path.join( pm.path.root, libName )
+                if libPath is None: libPath = os.path.join( pm.path.root, libName )
 
                 libFound = os.path.isfile(libPath)
                 if libFound: break
@@ -707,11 +712,10 @@ class ParaMonteSampler:
                         , marginBot = 1
                         )
 
-       #def isLoaded(libPath):
-       #    abslibPath =
-       #    return os.system("lsof -p {} | grep {} > /dev/null".format( os.getpid(), os.path.abspath(libPath) )) == 0
-
-        def dlclose(libdll): libdll.dlclose(libdll._handle)
+        #def isLoaded(libPath):
+        #    abslibPath =
+        #    return os.system("lsof -p {} | grep {} > /dev/null".format( os.getpid(), os.path.abspath(libPath) )) == 0
+        #def dlclose(libdll): libdll.dlclose(libdll._handle)
 
         if pm.platform.isWin32:
             handle = ct.windll.kernel32.LoadLibraryA(libPath)
@@ -962,7 +966,7 @@ class ParaMonteSampler:
 
             **Returns**
 
-                ???List
+                List
 
                     A Python list of ``TabularFileContents`` objects, each 
                     of which corresponds to the contents of a unique restart 
