@@ -1,40 +1,45 @@
 ####################################################################################################################################
 ####################################################################################################################################
 ####
+####   MIT License
+####
 ####   ParaMonte: plain powerful parallel Monte Carlo library.
 ####
 ####   Copyright (C) 2012-present, The Computational Data Science Lab
 ####
 ####   This file is part of the ParaMonte library.
 ####
-####   ParaMonte is free software: you can redistribute it and/or modify it
-####   under the terms of the GNU Lesser General Public License as published
-####   by the Free Software Foundation, version 3 of the License.
+####   Permission is hereby granted, free of charge, to any person obtaining a 
+####   copy of this software and associated documentation files (the "Software"), 
+####   to deal in the Software without restriction, including without limitation 
+####   the rights to use, copy, modify, merge, publish, distribute, sublicense, 
+####   and/or sell copies of the Software, and to permit persons to whom the 
+####   Software is furnished to do so, subject to the following conditions:
 ####
-####   ParaMonte is distributed in the hope that it will be useful,
-####   but WITHOUT ANY WARRANTY; without even the implied warranty of
-####   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-####   GNU Lesser General Public License for more details.
+####   The above copyright notice and this permission notice shall be 
+####   included in all copies or substantial portions of the Software.
 ####
-####   You should have received a copy of the GNU Lesser General Public License
-####   along with the ParaMonte library. If not, see,
-####
-####       https://github.com/cdslaborg/paramonte/blob/master/LICENSE
+####   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
+####   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
+####   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
+####   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
+####   DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
+####   OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
+####   OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ####
 ####   ACKNOWLEDGMENT
 ####
-####   As per the ParaMonte library license agreement terms,
-####   if you use any parts of this library for any purposes,
-####   we ask you to acknowledge the use of the ParaMonte library
-####   in your work (education/research/industry/development/...)
-####   by citing the ParaMonte library as described on this page:
+####   ParaMonte is an honor-ware and its currency is acknowledgment and citations.
+####   As per the ParaMonte library license agreement terms, if you use any parts of 
+####   this library for any purposes, kindly acknowledge the use of ParaMonte in your 
+####   work (education/research/industry/development/...) by citing the ParaMonte 
+####   library as described on this page:
 ####
 ####       https://github.com/cdslaborg/paramonte/blob/master/ACKNOWLEDGMENT.md
 ####
 ####################################################################################################################################
 ####################################################################################################################################
 
-import numpy as np
 import typing as tp
 import pandas as pd
 import weakref as wref
